@@ -10,19 +10,22 @@ vendor syntax.
 """
 
 __author__ = 'Jathan McCollum'
+__author__ = 'Jathan McCollum, Mike Biancaniello, Mike Harding'
 __maintainer__ = 'Jathan McCollum'
-__email__ = 'jathan.mccollum@teamaol.com'
+__email__ = 'jathanism@aol.com'
 __copyright__ = 'Copyright 2010-2012, AOL Inc.'
+__version__ = (0, 1)
 
 import os
 from trigger.conf import settings
-from trigger.acl.parser import *
 
-__all__ = ['acl_exists', 'parse', 'ACL']
-#__all__.extend(list(parser.__all__)) # Include parser.__all__ (duh!)
+__all__ = ['parser', 'acl_exists']
 
+# Parser
+from . import parser
+from parser import *
+__all__.extend(parser.__all__)
 
 # Functions
 def acl_exists(name):
     return os.access(settings.FIREWALL_DIR + '/acl.' + name, os.R_OK)
-
